Mapping from an authenticated caller to a persisted run author.
Functions
- run_
actor_ of - Build the
RunActorto persist for a run created byauth.
Mapping from an authenticated caller to a persisted run author.
RunActor to persist for a run created by auth.